==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/FOREIGNENTITYCOMMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FOREIGNENTITYCOMMENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FOREIGNENTITYCOMMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMENTTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYKEYCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FOREIGNENTITYCOMMENTID_Type", propOrder = {
    "entity",
    "commenttype",
    "entitykeycode"
})
public class FOREIGNENTITYCOMMENTID_Type {

    @XmlElement(name = "ENTITY", required = true)
    protected String entity;
    @XmlElement(name = "COMMENTTYPE", required = true)
    protected TYPE_Type commenttype;
    @XmlElement(name = "ENTITYKEYCODE", required = true)
    protected String entitykeycode;

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Obtient la valeur de la propriété commenttype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getCOMMENTTYPE() {
        return commenttype;
    }

    /**
     * Définit la valeur de la propriété commenttype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setCOMMENTTYPE(TYPE_Type value) {
        this.commenttype = value;
    }

    /**
     * Obtient la valeur de la propriété entitykeycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITYKEYCODE() {
        return entitykeycode;
    }

    /**
     * Définit la valeur de la propriété entitykeycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITYKEYCODE(String value) {
        this.entitykeycode = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/FOREIGNENTITYCOMMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FOREIGNENTITYCOMMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FOREIGNENTITYCOMMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMENTTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYKEYCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FOREIGNENTITYCOMMENTID_Type", propOrder = {
    "entity",
    "commenttype",
    "entitykeycode"
})
public class FOREIGNENTITYCOMMENTID_Type {

    @XmlElement(name = "ENTITY", required = true)
    protected String entity;
    @XmlElement(name = "COMMENTTYPE", required = true)
    protected TYPE_Type commenttype;
    @XmlElement(name = "ENTITYKEYCODE", required = true)
    protected String entitykeycode;

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Gets the value of the commenttype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getCOMMENTTYPE() {
        return commenttype;
    }

    /**
     * Sets the value of the commenttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setCOMMENTTYPE(TYPE_Type value) {
        this.commenttype = value;
    }

    /**
     * Gets the value of the entitykeycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITYKEYCODE() {
        return entitykeycode;
    }

    /**
     * Sets the value of the entitykeycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITYKEYCODE(String value) {
        this.entitykeycode = value;
    }

}
